"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTouchScrollDistance = void 0;
var _react = require("react");
var useTouchScrollDistance = () => {
  var [origin, setOrigin] = (0, _react.useState)(null);
  var [touches, setTouches] = (0, _react.useState)(null);
  /**
   * The distance between touch origin and touch current for both
   * x-axis and y-axis
   */
  var [touchScrollDistance, setTouchScrollDistance] = (0, _react.useState)({
    x: 0,
    y: 0
  });
  (0, _react.useEffect)(() => {
    var touchStartHandler = event => {
      if (origin === null) {
        setOrigin(event.touches);
      }
    };
    var touchMoveHandler = event => setTouches(event.changedTouches);
    var touchEndHandler = event => {
      if (event.touches.length === 0) {
        setOrigin(null);
        setTouches(null);
        setTouchScrollDistance({
          x: 0,
          y: 0
        });
      }
    };
    var touchCancelHandler = () => {
      setOrigin(null);
      setTouches(null);
      setTouchScrollDistance({
        x: 0,
        y: 0
      });
    };
    document.addEventListener('touchstart', touchStartHandler);
    document.addEventListener('touchmove', touchMoveHandler);
    document.addEventListener('touchend', touchEndHandler);
    document.addEventListener('touchcancel', touchCancelHandler);
    return () => {
      document.removeEventListener('touchstart', touchStartHandler);
      document.removeEventListener('touchmove', touchMoveHandler);
      document.removeEventListener('touchend', touchEndHandler);
      document.removeEventListener('touchcancel', touchCancelHandler);
    };
  }, [origin]);

  /**
   * Calculates the distance in pixels between the origin of
   * a touch event and position updates to that touch event.
   */
  (0, _react.useLayoutEffect)(() => {
    if (origin === null || touches === null) {
      return;
    }

    // User is not scrolling
    if (touches.length > 1) {
      return;
    }
    var deltaX = touches[0].clientX - origin[0].clientX;
    var deltaY = touches[0].clientY - origin[0].clientY;
    setTouchScrollDistance({
      x: deltaX,
      y: deltaY
    });
  }, [origin, touches]);
  return touchScrollDistance;
};
exports.useTouchScrollDistance = useTouchScrollDistance;